"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  getAverageColor: true,
  getPalette: true,
  getSegmentsAverageColor: true,
  getSegmentsPalette: true
};
exports.getSegmentsPalette = exports.getSegmentsAverageColor = exports.getPalette = exports.getAverageColor = void 0;
var _reactNative = require("react-native");
var _utils = require("./utils");
var _types = require("./types");
Object.keys(_types).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _types[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types[key];
    }
  });
});
const LINKING_ERROR = `The package 'react-native-image-palette' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';

// @ts-expect-error
const isTurboModuleEnabled = global.__turboModuleProxy != null;
const ImagePaletteModule = isTurboModuleEnabled ? require('./NativeImagePalette').default : _reactNative.NativeModules.ImagePalette;
const ImagePalette = ImagePaletteModule ?? new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
const getAverageColor = async (uri, config = {}) => {
  const resolvedSrc = (0, _utils.resolveImageSource)(uri);
  return ImagePalette.getAverageColor(resolvedSrc, config);
};
exports.getAverageColor = getAverageColor;
const getPalette = async (uri, config = {}) => {
  const resolvedSrc = (0, _utils.resolveImageSource)(uri);
  return ImagePalette.getPalette(resolvedSrc, config);
};
exports.getPalette = getPalette;
const getSegmentsAverageColor = async (uri, segments, config = {}) => {
  const resolvedSrc = (0, _utils.resolveImageSource)(uri);
  return ImagePalette.getSegmentsAverageColor(resolvedSrc, segments, config);
};
exports.getSegmentsAverageColor = getSegmentsAverageColor;
const getSegmentsPalette = async (uri, segments, config = {}) => {
  const resolvedSrc = (0, _utils.resolveImageSource)(uri);
  return ImagePalette.getSegmentsPalette(resolvedSrc, segments, config);
};
exports.getSegmentsPalette = getSegmentsPalette;
//# sourceMappingURL=index.js.map